import UtilEmpty from "./UtilEmpty";

export default class UtilValidate {
  /**
   * 是否邮箱
   * @param value
   * @returns {boolean}
   */
  static isEmail(value) {
    let reg = /^([a-zA-Z0-9_-])+@([a-zA-Z0-9_-])+((.[a-zA-Z0-9_-]{2,3}){1,2})$/;
    return reg.test(value);
  };

  /**
   * 是否手机号
   * @param value
   * @returns {boolean}
   */
  static isMobile(value) {
    return /^1[0-9]{10}$/.test(value);
  };

  /**
   * 是否座机号
   * @param value
   * @returns {boolean}
   */
  static isTelPhone(value) {
    return /^([0-9]{3,4}-)?[0-9]{7,8}$/.test(value);
  };

  /**
   * 是否座机或者手机号
   * @param value
   * @returns {*}
   */
  static isMobileOrTelPhone(value) {
    return UtilValidate.isTelPhone(value) || UtilValidate.isMobile(value);
  }

  /**
   * 是否请求路径
   * @param value
   * @returns {boolean}
   */
  static isURL(value) {
    return /^http[value]?:\/\/.*/.test(value);
  };

  /**
   * 是否数字
   * @param value
   * @returns {boolean}
   */
  static isNumber(value) {
    return Object.prototype.toString.call(value).slice(8, -1) === 'Number';
  };

  /**
   * 是否boolean
   * @param value
   * @returns {boolean}
   */
  static isBoolean(value) {
    return Object.prototype.toString.call(value).slice(8, -1) === 'Boolean';
  };

  /**
   * 是否Date
   * @param value
   * @returns {boolean}
   */
  static isDate(value) {
    return Object.prototype.toString.call(value).slice(8, -1) === 'Date';
  };

  /**
   * 是否身份证号
   * @param value
   * @returns {boolean}
   */
  static isIDCard(value) {
    if (!/(^\d{15}$)|(^\d{17}(\d|X|x)$)/.test(value)) {
      return false;
    }
    //身份证城市
    let aCity = {
      11: "北京",
      12: "天津",
      13: "河北",
      14: "山西",
      15: "内蒙古",
      21: "辽宁",
      22: "吉林",
      23: "黑龙江",
      31: "上海",
      32: "江苏",
      33: "浙江",
      34: "安徽",
      35: "福建",
      36: "江西",
      37: "山东",
      41: "河南",
      42: "湖北",
      43: "湖南",
      44: "广东",
      45: "广西",
      46: "海南",
      50: "重庆",
      51: "四川",
      52: "贵州",
      53: "云南",
      54: "西藏",
      61: "陕西",
      62: "甘肃",
      63: "青海",
      64: "宁夏",
      65: "新疆",
      71: "台湾",
      81: "香港",
      82: "澳门",
      91: "国外"
    };
    if (!aCity[parseInt(value.substr(0, 2))]) {
      return false
    }
    // 出生日期验证
    let sBirthday = (value.substr(6, 4) + "-" + Number(value.substr(10, 2)) + "-" + Number(value.substr(12, 2))).replace(/-/g, "/"),
      d = new Date(sBirthday);
    if (sBirthday !== (d.getFullYear() + "/" + (d.getMonth() + 1) + "/" + d.getDate())) {
      return false
    }
    //身份证号码校验
    let sum = 0,
      weights = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2],
      codes = "10X98765432";
    for (let i = 0; i < value.length - 1; i++) {
      sum += value[i] * weights[i];
    }
    //计算出来的最后一位身份证号码
    let last = codes[sum % 11];
    return value[value.length - 1] === last;
  };

  /**
   * 验证是否整数
   * @param value
   * @returns {boolean}
   */
  static isInt(value) {
    const re = /^[0-9]*[1-9][0-9]*$/;
    return re.test(value);
  }

  /**
   * 验证是否是[0-1]的小数
   * @param value
   * @returns {boolean}
   */
  static isDecimalZero2One(value) {
    if (UtilEmpty.number(value)) {
      return false;
    }
    return !(value < 0 || value > 1);
  }

  /**
   *  验证端口是否在[0,65535]之间
   * @param value
   * @returns {boolean}
   */
  static isPort(value) {
    const re = /^([0-9]|[1-9]\d|[1-9]\d{2}|[1-9]\d{3}|[1-5]\d{4}|6[0-4]\d{3}|65[0-4]\d{2}|655[0-2]\d|6553[0-5])$/;
    return re.test(value);
  }

  /**
   * 是否小写字母
   * @param value
   * @returns {boolean}
   */
  static isLowerCase(value) {
    const reg = /^[a-z]+$/;
    return reg.test(value);
  }

  /**
   * 是否大写字母
   * @param value
   * @returns {boolean}
   */
  static isUpperCase(value) {
    const reg = /^[A-Z]+$/;
    return reg.test(value);
  }

  /**
   * 是否是字母
   * @param value
   * @returns {boolean}
   */
  static isCase(value) {
    const reg = /^[A-Za-z]+$/;
    return reg.test(value);
  }

  /**
   * 字母或数字
   * @param value
   * @returns {boolean}
   */
  static isCaseOrNumber(value) {
    const reg = /[0-9a-zA-Z]/;
    return reg.test(value);
  }
}
